--[[ threshingFlowIndicator 

Author: 		HoFFi (modding-welt.com)

Description: 	script to animate a bar as indicator for threshing flow

Version: 		1.0.0.0

Changelog: 		2019-08-08 - initial release

--------------------------------------------------------------------------------------------------

XML:
	<threshingFlowIndicator indicatorBarNode="xxx" showInHud="false"/>
	
Explaination:
	indicatorBarNode = visual object (bar) to be scaled
	debug = if true, current flow will be displayed in hud. 

]]


threshingFlowIndicator = {};

threshingFlowIndicator.modDir = g_currentModDirectory;
threshingFlowIndicator.currentModName = g_currentModName;

function threshingFlowIndicator.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Combine, specializations); 
end;

function threshingFlowIndicator.registerEventListeners(vehicleType)
	for _, spec in pairs({"onLoad", "onDelete", "onUpdate", "onDraw", "onReadStream", "onWriteStream"}) do
		SpecializationUtil.registerEventListener(vehicleType, spec, threshingFlowIndicator)
	end
end

function threshingFlowIndicator:onLoad(savegame)
	self.indicatorBarNode = I3DUtil.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.threshingFlowIndicator#indicatorBarNode"), self.i3dMappings);
	self.showInHud = getXMLBool(self.xmlFile, "vehicle.threshingFlowIndicator#showInHud");
	self.currentFlow = 0
end;


function threshingFlowIndicator:onUpdate(dt)
	local spec = self.spec_combine
    if spec ~= nil then
		setScale(self.indicatorBarNode, 1, 1, 0);
        if spec.numAttachedCutters > 0 then
            for cutter, _ in pairs(spec.attachedCutters) do
                if cutter.getCutterLoad ~= nil then
					self.currentFlow = cutter:getCutterLoad()
					setScale(self.indicatorBarNode, 1, 1, self.currentFlow);
                end
            end
        end
    end

	
	
end;

function threshingFlowIndicator:onDelete()
end;

function threshingFlowIndicator:onReadStream(streamId, connection)
end;

function threshingFlowIndicator:onWriteStream(streamId, connection)
end;

function threshingFlowIndicator:onDraw(isActiveForInput, isSelected)
	if self.isClient then
		if isSelected then
			if self.showInHud then
				g_currentMission:addExtraPrintText(g_i18n:getText("Auslastung").." " .. MathUtil.round(self.currentFlow*100, 1) .. "%")
			end
		end
	end
end